diff src/sslconn.h @ 6720:41120df7ed94

[gaim-migrate @ 7247] Fixed documentation errors so Doxygen no longer complains. committer: Tailor Script <tailor@pidgin.im>
author Christian Hammond <chipx86@chipx86.com>
date Wed, 03 Sep 2003 05:21:04 +0000
parents 36897b9e009f
children 6c95f01aaf49
line wrap: on
line diff
--- a/src/sslconn.h	Wed Sep 03 04:49:24 2003 +0000
+++ b/src/sslconn.h	Wed Sep 03 05:21:04 2003 +0000
@@ -78,18 +78,18 @@
  *
  * @return The number of bytes read.
  */
-size_t gaim_ssl_read(GaimSslConnection *gsc, void *data, size_t len);
+size_t gaim_ssl_read(GaimSslConnection *gsc, void *buffer, size_t len);
 
 /**
  * Writes data to an SSL connection.
  *
  * @param gsc  The SSL connection handle.
  * @param data The data to write.
  * @param len  The length of the data to write.
  *
  * @return The number of bytes written.
  */
-size_t gaim_ssl_write(GaimSslConnection *gsc, const void *data, size_t len);
+size_t gaim_ssl_write(GaimSslConnection *gsc, const void *buffer, size_t len);
 
 /*@}*/
@@ -78,18 +78,18 @@
  * Writes data to an SSL connection.
  *
- * @param gsc  The SSL connection handle.
- * @param data The data to write.
- * @param len  The length of the data to write.
+ * @param gsc    The SSL connection handle.
+ * @param buffer The buffer to write.
+ * @param len    The length of the data to write.
  *
  * @return The number of bytes written.